==> haskell-mwc-random-0.13.3.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-mwc-random/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.13.3.2
id: mwc-random-0.13.3.2-98468153c4310cd751df6539413688b8
key: mwcra_0SEz8XRK7wOF4DF0uaF48y
license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.Distributions
    System.Random.MWC.CondensedTable
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/mwc-random-0.13.3.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/mwc-random-0.13.3.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/mwc-random-0.13.3.2
hs-libraries: HSmwc-random-0.13.3.2-0SEz8XRK7wOF4DF0uaF48y
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.13.4.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-mwc-random/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.13.4.0
id: mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
key: mwcra_0lrQ1SkkNA85sa8eZ98xQk
license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.Distributions
    System.Random.MWC.CondensedTable
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/mwc-random-0.13.4.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/mwc-random-0.13.4.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/mwc-random-0.13.4.0
hs-libraries: HSmwc-random-0.13.4.0-0lrQ1SkkNA85sa8eZ98xQk
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
